@@ -21,10 +21,11 @@ sub parse {
     while( $c->hasnext and ($c->nextline =~ $pattern ) ){
         my $l = $c->shiftline;
         $l =~ s{ $self->{pattern} }{$1}xmsg;
-        $l = "<tr><td>" . join( "</td><td>", split(/\|\|/, $l) ) . "</td></tr>";
+        $l = "<tr><td>" . join( "</td><td>",
+                                map {
+                                  $self->replace($_) # parse inline nodes
+                                } split(/\|\|/, $l) ) . "</td></tr>";
 
-        # parse inline nodes
-        $l = $self->replace($l);
         $c->htmllines($l);
     }
 
